@@ -312,7 +312,8 @@ int Application::newInstance()
     {
         if (hasToBeRecoveredFromCrash && !incognito)
         {
-            QTimer::singleShot(1000, tabWindow()->currentWebWindow(), SLOT(showCrashMessageBar()));
+            if (tabWindow() && tabWindow()->currentWebWindow())
+                QTimer::singleShot(1000, tabWindow()->currentWebWindow(), SLOT(showCrashMessageBar()));
         }
         else
         {
@@ -462,7 +463,9 @@ bool Application::eventFilter(QObject* watched, QEvent* event)
         TabWindow *window = qobject_cast<TabWindow*>(watched);
         if (window)
         {
-            if (m_tabWindows.at(0).data() != window)
+            if (!m_tabWindows.isEmpty() 
+                && m_tabWindows.at(0) 
+                && m_tabWindows.at(0).data() != window)
             {
                 int index = m_tabWindows.indexOf(QWeakPointer<TabWindow>(window));
                 Q_ASSERT(index != -1);
@@ -537,6 +540,7 @@ void Application::updateConfiguration()
     // ================ WebKit ============================
     defaultSettings->setAttribute(QWebSettings::DnsPrefetchEnabled, ReKonfig::dnsPrefetch());
     defaultSettings->setAttribute(QWebSettings::PrintElementBackgrounds, ReKonfig::printElementBackgrounds());
+    defaultSettings->setAttribute(QWebSettings::ZoomTextOnly, ReKonfig::zoomTextOnly());
 
     defaultSettings->setAttribute(QWebSettings::JavascriptEnabled, ReKonfig::javascriptEnabled());
     defaultSettings->setAttribute(QWebSettings::JavascriptCanOpenWindows, ReKonfig::javascriptCanOpenWindows());
