@@ -34,7 +34,6 @@
 #include "rekonq.h"
 
 // Local Includes
-#include "application.h"
 #include "historymanager.h"
 #include "iconmanager.h"
 
@@ -138,24 +137,26 @@ QVariant HistoryModel::data(const QModelIndex &index, int role) const
         case 1:
             return item.url;
         }
+        break;
     }
     case Qt::DecorationRole:
         if (index.column() == 0)
         {
-            return rApp->iconManager()->iconForUrl(item.url);
+            return IconManager::self()->iconForUrl(item.url);
         }
+        break;
     case Qt::ToolTipRole:
-        QString tooltip = "";
+        QString tooltip;
         if (!item.title.isEmpty())
-            tooltip = item.title + "<br/>";
+            tooltip = item.title + QL1S("<br/>");
 
         QString lastVisit = item.firstDateTimeVisit.toString(Qt::SystemLocaleDate);
         QString firstVisit = item.lastDateTimeVisit.toString(Qt::SystemLocaleDate);
         int visitCount = item.visitCount;
-        tooltip += "<center> <b>" + item.url + "</b> </center>";
-        tooltip += "<hr/>";
-        tooltip += i18n("First Visit: ") + firstVisit + "<br/>";
-        tooltip += i18n("Last Visit: ") + lastVisit + "<br/>";
+        tooltip += QL1S("<center> <b>") + item.url + QL1S("</b> </center>");
+        tooltip += QL1S("<hr/>");
+        tooltip += i18n("First Visit: ") + firstVisit + QL1S("<br/>");
+        tooltip += i18n("Last Visit: ") + lastVisit + QL1S("<br/>");
         tooltip += i18n("Number of Visits: ") + QString::number(visitCount);
 
         return tooltip;
@@ -224,12 +225,12 @@ void HistoryFilterModel::setSourceModel(QAbstractItemModel *newSourceModel)
     if (sourceModel())
     {
         disconnect(sourceModel(), SIGNAL(modelReset()), this, SLOT(sourceReset()));
-        disconnect(sourceModel(), SIGNAL(dataChanged(QModelIndex, QModelIndex)),
-                   this, SLOT(dataChanged(QModelIndex, QModelIndex)));
-        disconnect(sourceModel(), SIGNAL(rowsInserted(QModelIndex, int, int)),
-                   this, SLOT(sourceRowsInserted(QModelIndex, int, int)));
-        disconnect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex, int, int)),
-                   this, SLOT(sourceRowsRemoved(QModelIndex, int, int)));
+        disconnect(sourceModel(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
+                   this, SLOT(dataChanged(QModelIndex,QModelIndex)));
+        disconnect(sourceModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
+                   this, SLOT(sourceRowsInserted(QModelIndex,int,int)));
+        disconnect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
+                   this, SLOT(sourceRowsRemoved(QModelIndex,int,int)));
     }
 
     QAbstractProxyModel::setSourceModel(newSourceModel);
@@ -238,12 +239,12 @@ void HistoryFilterModel::setSourceModel(QAbstractItemModel *newSourceModel)
     {
         m_loaded = false;
         connect(sourceModel(), SIGNAL(modelReset()), this, SLOT(sourceReset()));
-        connect(sourceModel(), SIGNAL(dataChanged(QModelIndex, QModelIndex)),
-                this, SLOT(sourceDataChanged(QModelIndex, QModelIndex)));
-        connect(sourceModel(), SIGNAL(rowsInserted(QModelIndex, int, int)),
-                this, SLOT(sourceRowsInserted(QModelIndex, int, int)));
-        connect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex, int, int)),
-                this, SLOT(sourceRowsRemoved(QModelIndex, int, int)));
+        connect(sourceModel(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
+                this, SLOT(sourceDataChanged(QModelIndex,QModelIndex)));
+        connect(sourceModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
+                this, SLOT(sourceRowsInserted(QModelIndex,int,int)));
+        connect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
+                this, SLOT(sourceRowsRemoved(QModelIndex,int,int)));
     }
 }
 
@@ -405,16 +406,16 @@ bool HistoryFilterModel::removeRows(int row, int count, const QModelIndex &paren
     if (row < 0 || count <= 0 || row + count > rowCount(parent) || parent.isValid())
         return false;
     int lastRow = row + count - 1;
-    disconnect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex, int, int)),
-               this, SLOT(sourceRowsRemoved(QModelIndex, int, int)));
+    disconnect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
+               this, SLOT(sourceRowsRemoved(QModelIndex,int,int)));
     beginRemoveRows(parent, row, lastRow);
     int oldCount = rowCount();
     int start = sourceModel()->rowCount() - m_sourceRow.value(row);
     int end = sourceModel()->rowCount() - m_sourceRow.value(lastRow);
     sourceModel()->removeRows(start, end - start + 1);
     endRemoveRows();
-    connect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex, int, int)),
-            this, SLOT(sourceRowsRemoved(QModelIndex, int, int)));
+    connect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
+            this, SLOT(sourceRowsRemoved(QModelIndex,int,int)));
     m_loaded = false;
     if (oldCount - count != rowCount())
         reset();
@@ -452,7 +453,7 @@ QVariant HistoryTreeModel::data(const QModelIndex &index, int role) const
                 QDate date = idx.data(HistoryModel::DateRole).toDate();
                 if (date == QDate::currentDate())
                     return i18n("Earlier Today");
-                return date.toString(QL1S("dddd, MMMM d, yyyy"));
+                return date.toString(Qt::DefaultLocaleLongDate);
             }
             if (index.column() == 1)
             {
@@ -625,10 +626,10 @@ void HistoryTreeModel::setSourceModel(QAbstractItemModel *newSourceModel)
     {
         disconnect(sourceModel(), SIGNAL(modelReset()), this, SLOT(sourceReset()));
         disconnect(sourceModel(), SIGNAL(layoutChanged()), this, SLOT(sourceReset()));
-        disconnect(sourceModel(), SIGNAL(rowsInserted(QModelIndex, int, int)),
-                   this, SLOT(sourceRowsInserted(QModelIndex, int, int)));
-        disconnect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex, int, int)),
-                   this, SLOT(sourceRowsRemoved(QModelIndex, int, int)));
+        disconnect(sourceModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
+                   this, SLOT(sourceRowsInserted(QModelIndex,int,int)));
+        disconnect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
+                   this, SLOT(sourceRowsRemoved(QModelIndex,int,int)));
     }
 
     QAbstractProxyModel::setSourceModel(newSourceModel);
@@ -637,10 +638,10 @@ void HistoryTreeModel::setSourceModel(QAbstractItemModel *newSourceModel)
     {
         connect(sourceModel(), SIGNAL(modelReset()), this, SLOT(sourceReset()));
         connect(sourceModel(), SIGNAL(layoutChanged()), this, SLOT(sourceReset()));
-        connect(sourceModel(), SIGNAL(rowsInserted(QModelIndex, int, int)),
-                this, SLOT(sourceRowsInserted(QModelIndex, int, int)));
-        connect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex, int, int)),
-                this, SLOT(sourceRowsRemoved(QModelIndex, int, int)));
+        connect(sourceModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
+                this, SLOT(sourceRowsInserted(QModelIndex,int,int)));
+        connect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
+                this, SLOT(sourceRowsRemoved(QModelIndex,int,int)));
     }
 
     reset();
@@ -742,3 +743,35 @@ void HistoryTreeModel::sourceRowsRemoved(const QModelIndex &parent, int start, i
         endRemoveRows();
     }
 }
+
+
+// ----------------------------------------------------------------------------------------------------------
+
+
+UrlFilterProxyModel::UrlFilterProxyModel(QObject *parent)
+    : QSortFilterProxyModel(parent)
+{
+    setFilterCaseSensitivity(Qt::CaseInsensitive);
+}
+
+
+bool UrlFilterProxyModel::filterAcceptsRow(const int source_row, const QModelIndex &source_parent) const
+{
+    return recursiveMatch(sourceModel()->index(source_row, 0, source_parent));
+}
+
+
+bool UrlFilterProxyModel::recursiveMatch(const QModelIndex &index) const
+{
+    if (index.data().toString().contains(filterRegExp()))
+        return true;
+
+    int numChildren = sourceModel()->rowCount(index);
+    for (int childRow = 0; childRow < numChildren; ++childRow)
+    {
+        if (recursiveMatch(sourceModel()->index(childRow, 0, index)))
+            return true;
+    }
+
+    return false;
+}
