@@ -26,8 +26,8 @@
 * ============================================================ */
 
 
-#ifndef HISTORYMODELS_H
-#define HISTORYMODELS_H
+#ifndef HISTORY_MODELS_H
+#define HISTORY_MODELS_H
 
 
 // Rekonq Includes
@@ -40,12 +40,13 @@
 #include <QHash>
 #include <QAbstractTableModel>
 #include <QAbstractProxyModel>
+#include <QSortFilterProxyModel>
 
 // Forward Declarations
 class HistoryManager;
 
 
-class REKONQ_TESTS_EXPORT HistoryModel : public QAbstractTableModel
+class HistoryModel : public QAbstractTableModel
 {
     Q_OBJECT
 
@@ -86,7 +87,7 @@ private:
  * the front of the list, but as offsets from the back.
  *
  */
-class REKONQ_TESTS_EXPORT HistoryFilterModel : public QAbstractProxyModel
+class HistoryFilterModel : public QAbstractProxyModel
 {
     Q_OBJECT
 
@@ -176,4 +177,28 @@ private:
 };
 
 
-#endif // HISTORYMODELS_H
+// ----------------------------------------------------------------------------------------------------------------------
+
+
+/**
+ * QSortFilterProxyModel hides all children which parent doesn't
+ * match the filter. This class is used to change this behavior.
+ * If a url matches the filter it'll be shown,
+ * even if it's parent doesn't match it.
+ */
+class UrlFilterProxyModel : public QSortFilterProxyModel
+{
+    Q_OBJECT
+
+public:
+    explicit UrlFilterProxyModel(QObject *parent = 0);
+
+protected:
+    virtual bool filterAcceptsRow(const int source_row, const QModelIndex &source_parent) const;
+
+    // returns true if index or any of his children match the filter
+    bool recursiveMatch(const QModelIndex &index) const;
+};
+
+
+#endif // HISTORY_MODELS_H
