@@ -3,7 +3,7 @@
 * This file is a part of the rekonq project
 *
 * Copyright (C) 2007 David Faure <faure@kde.org>
-* Copyright (C) 2009-2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2009-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 *
 *
 * This program is free software; you can redistribute it and/or
@@ -59,25 +59,14 @@
 #  endif
 #endif //ASSERT_NOT_REACHED
 
-// ----------------------------------------------------------------------------------------------------
+
+// --------------------------------------------------------------------------------------
 // ENUMS
 
+
 namespace Rekonq
 {
 
-/**
-* @short notifying message status
-* Different message status
-*/
-enum Notify
-{
-    Success,    ///< url successfully (down)loaded
-    Error,      ///< url failed to (down)load
-    Download,   ///< downloading url
-    Info,       ///< information
-    Url         ///< url string shown (default)
-};
-
 /**
 * @short Open link options
 * Different modes of opening new tab
@@ -88,7 +77,8 @@ enum OpenType
     NewTab,             ///< open url according to users settings
     NewFocusedTab,      ///< open url in new tab and focus it
     NewBackGroundTab,   ///< open url in new background tab
-    NewWindow           ///< open url in new window
+    NewWindow,          ///< open url in new window
+    NewPrivateWindow    ///< open url in new private window
 };
 
 /**
