@@ -33,7 +33,6 @@
 #include "rekonq.h"
 
 // Local Includes
-#include "application.h"
 #include "bookmarkmanager.h"
 
 // KDE Includes
@@ -169,7 +168,7 @@ void OperaSyncHandler::startLogin()
 
         if (_qoauth.error() != QOAuth::NoError)
         {
-            kDebug() << "Error occured while fetching request tokens. Error code is : " << _qoauth.error();
+            kDebug() << "Error occurred while fetching request tokens. Error code is : " << _qoauth.error();
             emit syncStatus(Rekonq::Bookmarks, false, i18n("OAuth : Error fetching request token."));
             _isSyncing = false;
             return;
@@ -293,7 +292,13 @@ void OperaSyncHandler::getBookmarks()
     kDebug() << "Auth Token Secret : " << _authTokenSecret;
 
     QByteArray fetchBookmarksUrl = "https://link.api.opera.com/rest/bookmark/descendants/";
-    QByteArray urlParams = _qoauth.createParametersString(fetchBookmarksUrl, QOAuth::GET, _authToken, _authTokenSecret, QOAuth::HMAC_SHA1, requestMap, QOAuth::ParseForInlineQuery);
+    QByteArray urlParams = _qoauth.createParametersString(fetchBookmarksUrl,
+                           QOAuth::GET,
+                           _authToken,
+                           _authTokenSecret,
+                           QOAuth::HMAC_SHA1,
+                           requestMap,
+                           QOAuth::ParseForInlineQuery);
 
     QNetworkRequest request;
 
@@ -302,7 +307,7 @@ void OperaSyncHandler::getBookmarks()
     KIO::TransferJob *job = KIO::get(KUrl(fetchBookmarksUrl), KIO::Reload, KIO::HideProgressInfo);
 
     connect(job, SIGNAL(result(KJob*)), this, SLOT(fetchBookmarksResultSlot(KJob*)));
-    connect(job, SIGNAL(data(KIO::Job*, QByteArray)), this, SLOT(fetchBookmarksDataSlot(KIO::Job*, QByteArray)));
+    connect(job, SIGNAL(data(KIO::Job*,QByteArray)), this, SLOT(fetchBookmarksDataSlot(KIO::Job*,QByteArray)));
 }
 
 void OperaSyncHandler::fetchBookmarksDataSlot(KIO::Job* job, QByteArray data)
@@ -335,7 +340,7 @@ void OperaSyncHandler::fetchBookmarksResultSlot(KJob* job)
     doc.setContent(_xmlData);
     QDomNodeList responseList = doc.elementsByTagName("response");
 
-    KBookmarkGroup root = rApp->bookmarkManager()->rootGroup();
+    KBookmarkGroup root = BookmarkManager::self()->rootGroup();
 
     if (_mode == RECEIVE_CHANGES)
     {
@@ -455,7 +460,7 @@ void OperaSyncHandler::createBookmarkFolderResultSlot(KJob* job)
 
     if (job->error() != 0)
     {
-        kDebug() << "Error occured while creating bookmark folder on server. Error code : " << job->error();
+        kDebug() << "Error occurred while creating bookmark folder on server. Error code : " << job->error();
         decreaseRequestCount();
         return;
     }
@@ -513,7 +518,7 @@ void OperaSyncHandler::handleBookmark(const QDomElement &item, KBookmarkGroup ro
         if (_mode == RECEIVE_CHANGES)
         {
             root.addBookmark(title, KUrl(url));
-            rApp->bookmarkManager()->manager()->emitChanged(root);
+            BookmarkManager::self()->manager()->emitChanged(root);
         }
         else
         {
@@ -566,7 +571,7 @@ void OperaSyncHandler::handleResource(const QDomNode &item, KBookmarkGroup &root
             if (childGroup.isNull())
             {
                 childGroup = root.createNewFolder(title);
-                rApp->bookmarkManager()->manager()->emitChanged(root);
+                BookmarkManager::self()->manager()->emitChanged(root);
             }
 
             handleBookmarkFolder(element, childGroup);
@@ -684,7 +689,7 @@ void OperaSyncHandler::addBookmarkOnServer(QString title, QString url, QString p
     job->addMetaData("Content-Type", "application/x-www-form-urlencoded");
 
     connect(job, SIGNAL(result(KJob*)), this, SLOT(createBookmarkResultSlot(KJob*)));
-    connect(job, SIGNAL(data(KIO::Job*, QByteArray)), this, SLOT(createBookmarkDataSlot(KIO::Job*, QByteArray)));
+    connect(job, SIGNAL(data(KIO::Job*,QByteArray)), this, SLOT(createBookmarkDataSlot(KIO::Job*,QByteArray)));
 
     ++_requestCount;
 }
@@ -711,7 +716,7 @@ KJob *OperaSyncHandler::addBookmarkFolderOnServer(QString title, QString parent)
     _jobToResponseMap.insert(job, "");
 
     connect(job, SIGNAL(result(KJob*)), this, SLOT(createBookmarkFolderResultSlot(KJob*)));
-    connect(job, SIGNAL(data(KIO::Job*, QByteArray)), this, SLOT(createBookmarkFolderDataSlot(KIO::Job*, QByteArray)));
+    connect(job, SIGNAL(data(KIO::Job*,QByteArray)), this, SLOT(createBookmarkFolderDataSlot(KIO::Job*,QByteArray)));
 
     ++_requestCount;
     return job;
@@ -740,7 +745,7 @@ void OperaSyncHandler::deleteResourceOnServer(QString id)
     job->addMetaData("Content-Type", "application/x-www-form-urlencoded");
 
     connect(job, SIGNAL(result(KJob*)), this, SLOT(deleteResourceResultSlot(KJob*)));
-    connect(job, SIGNAL(data(KIO::Job*, QByteArray)), this, SLOT(deleteResourceDataSlot(KIO::Job*, QByteArray)));
+    connect(job, SIGNAL(data(KIO::Job*,QByteArray)), this, SLOT(deleteResourceDataSlot(KIO::Job*,QByteArray)));
 
     ++_requestCount;
 }
