@@ -41,6 +41,7 @@
 
 #include "bookmarkmanager.h"
 #include "iconmanager.h"
+#include "sessionmanager.h"
 
 // KDE Includes
 #include <KAction>
@@ -154,6 +155,16 @@ void TabWindow::init()
     actionCollection()->addAction(QL1S("close_tab"), a);
     connect(a, SIGNAL(triggered(bool)), this, SLOT(closeTab()));
 
+    a = new KAction(i18n("Show Next Tab"), this);
+    a->setShortcuts(QApplication::isRightToLeft() ? KStandardShortcut::tabPrev() : KStandardShortcut::tabNext());
+    actionCollection()->addAction(QL1S("show_next_tab"), a);
+    connect(a, SIGNAL(triggered(bool)), this, SLOT(nextTab()));
+
+    a = new KAction(i18n("Show Previous Tab"), this);
+    a->setShortcuts(QApplication::isRightToLeft() ? KStandardShortcut::tabNext() : KStandardShortcut::tabPrev());
+    actionCollection()->addAction(QL1S("show_prev_tab"), a);
+    connect(a, SIGNAL(triggered(bool)), this, SLOT(previousTab()));
+
     a = KStandardAction::fullScreen(this, SLOT(setFullScreen(bool)), this, actionCollection());
     KShortcut fullScreenShortcut = KStandardShortcut::fullScreen();
     fullScreenShortcut.setAlternate(Qt::Key_F11);
@@ -198,6 +209,17 @@ void TabWindow::init()
     connect(favoritesSignalMapper, SIGNAL(mapped(int)), this, SLOT(loadFavorite(int)));
 
     _ac->readSettings();
+    
+    // ----------------------------------------------------------------------------------------------
+    int n = rApp->tabWindowList().count() + 1;
+    QList<TabHistory> list = SessionManager::self()->closedSitesForWindow( QL1S("win") + QString::number(n) );
+    Q_FOREACH(const TabHistory & tab, list)
+    {
+        if (tab.url.startsWith(QL1S("about")))
+            continue;
+        m_recentlyClosedTabs.removeAll(tab);
+        m_recentlyClosedTabs.prepend(tab);
+    }
 }
 
 
@@ -242,6 +264,12 @@ WebWindow *TabWindow::webWindow(int index) const
 }
 
 
+QList<TabHistory> TabWindow::recentlyClosedTabs()
+{
+    return m_recentlyClosedTabs;
+}
+
+
 WebWindow *TabWindow::prepareNewTab(WebPage *page)
 {
     WebWindow *tab = new WebWindow(this, _isPrivateBrowsing, page);
@@ -266,6 +294,14 @@ void TabWindow::loadUrl(const KUrl &url, Rekonq::OpenType type, TabHistory *hist
     switch (type)
     {
     case Rekonq::NewTab:
+        tab = prepareNewTab();
+        _openedTabsCounter++;
+        insertTab(currentIndex() + _openedTabsCounter, tab, i18n("new tab"));
+        if (ReKonfig::openNewTabsInForeground())
+        {
+            setCurrentWidget(tab);
+        }
+        break;
     case Rekonq::NewBackGroundTab:
         tab = prepareNewTab();
         _openedTabsCounter++;
@@ -688,29 +724,64 @@ void TabWindow::bookmarkAllTabs()
 
 
 void TabWindow::restoreLastClosedTab()
+{
+    restoreClosedTab(0);
+}
+
+
+void TabWindow::restoreClosedTab(int index, bool inNewTab)
 {
     if (m_recentlyClosedTabs.isEmpty())
         return;
-
-    TabHistory history = m_recentlyClosedTabs.takeAt(0);
+    
+    if (index >= m_recentlyClosedTabs.count())
+        return;
+    
+    TabHistory history = m_recentlyClosedTabs.takeAt(index);
 
     QUrl u = QUrl(history.url);
 
     int restorePosition = history.position;
 
-    WebWindow *tab = prepareNewTab();
+    WebWindow *tab;
 
-    if (restorePosition < count())
-        insertTab(restorePosition, tab, i18n("restored tab"));
+    if (inNewTab)
+    {
+        tab = prepareNewTab();
+        if (restorePosition < count())
+            insertTab(restorePosition, tab, i18n("restored tab"));
+        else
+            addTab(tab, i18n("restored tab"));
+
+        setCurrentWidget(tab);
+    }
     else
-        addTab(tab, i18n("restored tab"));
-
-    setCurrentWidget(tab);
-
+    {
+        tab = currentWebWindow();
+    }
+    
     tab->load(u);
 
     // just to get sure...
-    m_recentlyClosedTabs.removeAll(history);
+    m_recentlyClosedTabs.removeAll(history);    
+}
+
+
+void TabWindow::nextTab()
+{
+    int next = currentIndex() + 1;
+    if (next == count())
+        next = 0;
+    setCurrentIndex(next);
+}
+
+
+void TabWindow::previousTab()
+{
+    int next = currentIndex() - 1;
+    if (next < 0)
+        next = count() - 1;
+    setCurrentIndex(next);
 }
 
 
