@@ -250,7 +250,7 @@ bool WebView::popupSpellMenu(QContextMenuEvent *event)
                 QString script(QL1S("this.value=this.value.substring(0,"));
                 script += QString::number(s1);
                 script += QL1S(") + \'");
-                script +=  w;
+                script +=  w.replace('\'', "\\\'"); // Escape any Quote marks in replacement word
                 script += QL1C('\'') + QL1S("+this.value.substring(");
                 script += QString::number(s2);
                 script += QL1C(')');
@@ -479,13 +479,13 @@ void WebView::contextMenuEvent(QContextMenuEvent *event)
                 // open selected text url in a new tab
                 QAction * const openInNewTabAction = new KAction(KIcon("tab-new"),
                         i18n("Open '%1' in New Tab", truncatedUrl), &menu);
-                openInNewTabAction->setData(QUrl(urlLikeText));
+                openInNewTabAction->setData( QUrl::fromUserInput(selectedText()) );
                 connect(openInNewTabAction, SIGNAL(triggered(bool)), this, SLOT(openLinkInNewTab()));
                 menu.addAction(openInNewTabAction);
                 //open selected text url in a new window
                 QAction * const openInNewWindowAction = new KAction(KIcon("window-new"),
                         i18n("Open '%1' in New Window", truncatedUrl), &menu);
-                openInNewWindowAction->setData(QUrl(urlLikeText));
+                openInNewWindowAction->setData( QUrl::fromUserInput(selectedText()) );
                 connect(openInNewWindowAction, SIGNAL(triggered(bool)), this, SLOT(openLinkInNewWindow()));
                 menu.addAction(openInNewWindowAction);
                 menu.addSeparator();
@@ -609,7 +609,7 @@ void WebView::mousePressEvent(QMouseEvent *event)
         case 1: // Load Clipboard URL
             if (weCanDoMiddleClickActions)
             {
-                const QString clipboardContent = QApplication::clipboard()->text();
+                const QString clipboardContent = QApplication::clipboard()->text(QClipboard::Selection);
 
                 if (clipboardContent.isEmpty())
                     break;
@@ -634,6 +634,10 @@ void WebView::mousePressEvent(QMouseEvent *event)
         break;
     };
 
+    // If Control was pressed, do not display Access Keys upon release.
+    if (ReKonfig::accessKeysEnabled() && event->modifiers() == Qt::ControlModifier)
+        m_accessKeysPressed = false;
+
     KWebView::mousePressEvent(event);
 }
 
@@ -717,7 +721,7 @@ void WebView::search()
     KService::Ptr engine = KService::serviceByDesktopPath(a->data().toString());
     KUrl urlSearch = KUrl(SearchEngine::buildQuery(engine, selectedText()));
 
-    emit loadUrl(urlSearch, Rekonq::NewTab);
+    emit loadUrl(urlSearch, Rekonq::NewFocusedTab);
 }
 
 
@@ -1429,7 +1433,6 @@ void WebView::spellCheck()
     backgroundSpellCheck->setParent(spellDialog);
     spellDialog->setAttribute(Qt::WA_DeleteOnClose, true);
 
-    spellDialog->showSpellCheckCompletionMessage(true);
     connect(spellDialog, SIGNAL(replace(QString,int,QString)), this, SLOT(spellCheckerCorrected(QString,int,QString)));
     connect(spellDialog, SIGNAL(misspelling(QString,int)), this, SLOT(spellCheckerMisspelling(QString,int)));
     if (m_contextMenuHitResult.isContentSelected())
@@ -1451,7 +1454,8 @@ void WebView::spellCheckerCorrected(const QString& original, int pos, const QStr
     QString script(QL1S("this.value=this.value.substring(0,"));
     script += QString::number(index);
     script += QL1S(") + \"");
-    script +=  replacement;
+    QString w(replacement);
+    script +=  w.replace('\'', "\\\'"); // Escape any Quote marks in replacement word
     script += QL1S("\" + this.value.substring(");
     script += QString::number(index + original.length());
     script += QL1S(")");
