@@ -61,8 +61,10 @@
 #include <KUrl>
 #include <KToolBar>
 #include <KToggleFullScreenAction>
-#include <KShortcutsEditor>
+#include <KShortcutsDialog>
+#include <KRun>
 
+// Qt Includes
 #include <QLabel>
 #include <QStyle>
 #include <QTextDocument>
@@ -282,6 +284,7 @@ void WebWindow::setupActions()
     connect(a, SIGNAL(triggered(bool)), this, SLOT(viewPageSource()));
 
     a = new KAction(KIcon("view-media-artist"), i18n("New Private Window"), this);
+    a->setShortcut(KShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_N));
     connect(a, SIGNAL(triggered(bool)), rApp, SLOT(newPrivateBrowsingWindow()));
     actionCollection()->addAction(QL1S("private_browsing"), a);
 
@@ -303,6 +306,14 @@ void WebWindow::setupActions()
 
     // Edit bookmarks
     a = KStandardAction::editBookmarks(BookmarkManager::self(), SLOT(slotEditBookmarks()), actionCollection());
+    
+    // Bookmark Menu
+    KActionMenu *bmMenu = BookmarkManager::self()->bookmarkActionMenu(this);
+    bmMenu->setIcon(KIcon("bookmarks"));
+    bmMenu->setDelayed(false);
+    bmMenu->setShortcutConfigurable(true);
+    bmMenu->setShortcut(KShortcut(Qt::ALT + Qt::Key_B));
+    actionCollection()->addAction(QL1S("bookmarksActionMenu"), bmMenu);
 
     // User Agent
     a = new KAction(KIcon("preferences-web-browser-identification"), i18n("Browser Identification"), this);
@@ -979,35 +990,28 @@ void WebWindow::keyPressEvent(QKeyEvent *kev)
 
 void WebWindow::keyBindings()
 {
-    QPointer<KDialog> dialog = new KDialog(this);
+    QPointer<KShortcutsDialog> dialog = new KShortcutsDialog(KShortcutsEditor::AllActions, KShortcutsEditor::LetterShortcutsAllowed, this);
 
-    KShortcutsEditor widget(this);
-
-    widget.addCollection(actionCollection(), i18n("web window"));
+    dialog->addCollection(actionCollection(), i18n("web window"));
     TabWindow *tw = rApp->tabWindow();
     if (tw)
     {
-        widget.addCollection(tw->actionCollection(), i18n("tab window"));
-    }
-    
-    dialog->setMainWidget(&widget);
-
-    dialog->setCaption(i18nc("@title:window", "Configure Shortcuts"));
-    dialog->setButtons(KDialog::Ok | KDialog::Cancel | KDialog::Reset);
-    dialog->setMinimumSize(700, 525);
-
-    connect(dialog, SIGNAL(resetClicked()), &widget, SLOT(allDefault()));
-    
-    if (dialog->exec() == QDialog::Accepted)
-    {
-        kDebug() << "OK";
-        widget.save();
+        dialog->addCollection(tw->actionCollection(), i18n("tab window"));
     }
 
+    dialog->configure();
     dialog->deleteLater();
 }
 
 
+
+void WebWindow::findSelectedText()
+{
+    // Just done everything! Just show findbar... ;)
+    m_findBar->show();
+}
+
+
 // Main Toolbar methods ----------
 
 
